@@ -38,23 +38,25 @@ class CreateVpcEndpointRequest(RpcRequest):
 	def set_ClientToken(self,ClientToken):
 		self.add_query_param('ClientToken',ClientToken)
 
-	def get_SecurityGroupId(self):
+	def get_SecurityGroupIds(self):
 		return self.get_query_params().get('SecurityGroupId')
 
-	def set_SecurityGroupId(self, SecurityGroupIds):
+	def set_SecurityGroupIds(self, SecurityGroupIds):
 		for depth1 in range(len(SecurityGroupIds)):
 			if SecurityGroupIds[depth1] is not None:
 				self.add_query_param('SecurityGroupId.' + str(depth1 + 1) , SecurityGroupIds[depth1])
 
-	def get_Zone(self):
+	def get_Zones(self):
 		return self.get_query_params().get('Zone')
 
-	def set_Zone(self, Zones):
+	def set_Zones(self, Zones):
 		for depth1 in range(len(Zones)):
 			if Zones[depth1].get('VSwitchId') is not None:
 				self.add_query_param('Zone.' + str(depth1 + 1) + '.VSwitchId', Zones[depth1].get('VSwitchId'))
 			if Zones[depth1].get('ZoneId') is not None:
 				self.add_query_param('Zone.' + str(depth1 + 1) + '.ZoneId', Zones[depth1].get('ZoneId'))
+			if Zones[depth1].get('ip') is not None:
+				self.add_query_param('Zone.' + str(depth1 + 1) + '.ip', Zones[depth1].get('ip'))
 
 	def get_ServiceName(self):
 		return self.get_query_params().get('ServiceName')
